@@ -8,7 +8,7 @@ import (
 	"github.com/ghodss/yaml"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
-	v1 "github.com/openshift-kni/performance-addon-operators/pkg/apis/performance/v1"
+	performancev2 "github.com/openshift-kni/performance-addon-operators/api/v2"
 	"github.com/openshift-kni/performance-addon-operators/pkg/controller/performanceprofile/components"
 	testutils "github.com/openshift-kni/performance-addon-operators/pkg/utils/testing"
 
@@ -22,7 +22,6 @@ const expectedMatchSelector = `
 `
 
 var (
-	clusterVersion                     = "4.6.27"
 	cmdlineCPUsPartitioning            = regexp.MustCompile(`\s*cmdline_cpu_part=\+\s*nohz=on\s+rcu_nocbs=\${isolated_cores}\s+tuned.non_isolcpus=\${not_isolated_cpumask}\s+intel_pstate=disable\s+nosoftlockup\s*`)
 	cmdlineRealtimeWithCPUBalancing    = regexp.MustCompile(`\s*cmdline_realtime=\+\s*tsc=nowatchdog\s+intel_iommu=on\s+iommu=pt\s+isolcpus=managed_irq,\${isolated_cores}\s+systemd.cpu_affinity=\${not_isolated_cores_expanded}\s*`)
 	cmdlineRealtimeWithoutCPUBalancing = regexp.MustCompile(`\s*cmdline_realtime=\+\s*tsc=nowatchdog\s+intel_iommu=on\s+iommu=pt\s+isolcpus=domain,managed_irq,\${isolated_cores}\s+systemd.cpu_affinity=\${not_isolated_cores_expanded}\s*`)
@@ -35,14 +34,14 @@ var (
 var additionalArgs = []string{"test1=val1", "test2=val2"}
 
 var _ = Describe("Tuned", func() {
-	var profile *v1.PerformanceProfile
+	var profile *performancev2.PerformanceProfile
 
 	BeforeEach(func() {
 		profile = testutils.NewPerformanceProfile("test")
 	})
 
-	getTunedManifest := func(profile *v1.PerformanceProfile) string {
-		tuned, err := NewNodePerformance(testAssetsDir, profile, clusterVersion)
+	getTunedManifest := func(profile *performancev2.PerformanceProfile) string {
+		tuned, err := NewNodePerformance(testAssetsDir, profile)
 		Expect(err).ToNot(HaveOccurred())
 		y, err := yaml.Marshal(tuned)
 		Expect(err).ToNot(HaveOccurred())
@@ -91,28 +90,10 @@ var _ = Describe("Tuned", func() {
 			Expect(strings.Count(manifest, "hugepages=")).Should(BeNumerically("==", 2))
 		})
 
-		It("should generate yaml with stalld enabled", func() {
-			clusterVersion = "4.6.27"
-			manifest := getTunedManifest(profile)
-			Expect(manifest).To(ContainSubstring("service.stalld=start,enable"))
-		})
-
-		It("should not generate yaml with stalld enabled", func() {
-			clusterVersion = "4.6.26"
-			manifest := getTunedManifest(profile)
-			Expect(manifest).ToNot(ContainSubstring("service.stalld=start,enable"))
-		})
-
-		It("should generate yaml with stalld enabled for non stable release", func() {
-			clusterVersion = "4.6.0-0.ci-2021-05-27-162213"
-			manifest := getTunedManifest(profile)
-			Expect(manifest).To(ContainSubstring("service.stalld=start,enable"))
-		})
-
 		Context("with 1G default huge pages", func() {
 			Context("with requested 2M huge pages allocation on the specified node", func() {
 				It("should append the dummy 2M huge pages kernel arguments", func() {
-					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, v1.HugePage{
+					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, performancev2.HugePage{
 						Size:  components.HugepagesSize2M,
 						Count: 128,
 						Node:  pointer.Int32Ptr(0),
@@ -125,7 +106,7 @@ var _ = Describe("Tuned", func() {
 
 			Context("with requested 2M huge pages allocation via kernel arguments", func() {
 				It("should not append the dummy 2M kernel arguments", func() {
-					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, v1.HugePage{
+					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, performancev2.HugePage{
 						Size:  components.HugepagesSize2M,
 						Count: 128,
 					})
@@ -145,12 +126,12 @@ var _ = Describe("Tuned", func() {
 
 			Context("with requested 2M huge pages allocation on the specified node and via kernel arguments", func() {
 				It("should not append the dummy 2M kernel arguments", func() {
-					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, v1.HugePage{
+					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, performancev2.HugePage{
 						Size:  components.HugepagesSize2M,
 						Count: 128,
 						Node:  pointer.Int32Ptr(0),
 					})
-					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, v1.HugePage{
+					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, performancev2.HugePage{
 						Size:  components.HugepagesSize2M,
 						Count: 128,
 					})
@@ -165,9 +146,9 @@ var _ = Describe("Tuned", func() {
 		Context("with 2M default huge pages", func() {
 			Context("with requested 2M huge pages allocation on the specified node", func() {
 				It("should not append the dummy 2M huge pages kernel arguments", func() {
-					defaultSize := v1.HugePageSize(components.HugepagesSize2M)
+					defaultSize := performancev2.HugePageSize(components.HugepagesSize2M)
 					profile.Spec.HugePages.DefaultHugePagesSize = &defaultSize
-					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, v1.HugePage{
+					profile.Spec.HugePages.Pages = append(profile.Spec.HugePages.Pages, performancev2.HugePage{
 						Size:  components.HugepagesSize2M,
 						Count: 128,
 						Node:  pointer.Int32Ptr(0),
